<?php

if(!class_exists('WP_List_Table')){
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class WpbcBacklinksGroupTable extends WP_List_Table {

	private $data;
	private $wpdb;
	private $wpbcdb;

	public function __construct( $wpdb ){
		$this->wpdb 	= $wpdb;
		$this->wpbcdb 	= new WpbcDb( $this->wpdb );
		$this->data 	= $this->wpbcdb->get_backlinks_groups( );
		parent::__construct( array(
			'singular'  => 'Backlink Group',
			'plural'    => 'Backlink Groups',
			'ajax'      => false
		) );
	}
	public function column_default( $item, $column_name ){
        	switch( $column_name ){
            		case 'cb':
                		return '<input type="checkbox" />';
            		case 'name':
				return '<a href="?page='. $_REQUEST['page'] . '&wpbc_gid='. $item['id'] .'">'.
						$item['name'] . '</a>';
            		case 'creator_id':
				$user = get_userdata( $item['creator_id'] ); 
                		return $user->user_login;
            		case 'description':
				return $item['description'];
            		case 'backlinks':
				return '<a href="?page='. $_REQUEST['page'] . '&wpbc_gid='. $item['id'] .'">'.
						 count($this->wpbcdb->get_backlinks( $item['id'] )). '</a>';
            		case 'timestamp':
                		return date("D d M Y",  $item['timestamp']);
            		case 'notifications':
                		$notify =  ($item['notify'] == 1) ? 'ON' : 'OFF';
                		$not =  ($item['notify'] == 1) ? 0 : 1;
				return '<a href="?page='. $_REQUEST['page'] .
					'&action=notify&notify='. $item['id'] .
					'&not='. $not .'">'. $notify .'</a>';
            		case 'remind':
                		$remind =  ($item['remind_days'] > 0 ) ? $item['remind_days'] . ' days': 'Never';
				return $remind;
            		default:
                		return '';
        	}
    	}
	public function column_cb( $item ){
		return '<input type="checkbox" name="wpbc_bgroup_delete[]" value="'. $item['id'] .'"/>';
	}
	public function column_name( $item ){
		$actions = array(
				'edit'      => sprintf('<a href="?page=%s&action=%s&edit=%s">Edit</a>', $_REQUEST['page'],'edit',$item['id']),
 			);
        	return sprintf('%1$s %2$s',	
        	    /*$1%s*/ '<a href="?page='. $_REQUEST['page'] . '&wpbc_gid='. $item['id'] .'">'.
						$item['name'] . '</a>',
        	    /*$2%s*/ $this->row_actions($actions)
        	);
	}
	public function get_bulk_actions() {
        	$actions = array(
            		'delete'    => 'Delete'
        		);
        	return $actions;
	}
	public function process_bulk_action() {
	}
	public function get_columns(){
		$columns = array(
			'cb'        		=> '<input type="checkbox" />',
			'name'    		=> 'Group Name',
			'description'    	=> 'Description',
			'backlinks'    		=> 'Backlinks',
			'timestamp'    		=> 'Created',
			'notifications'    	=> 'Change Notifications',
			'remind'    		=> 'Renewal Reminder',
        	);
		return $columns;
	}  
	public function get_sortable_columns() {
		$sortable_columns = array(
			'notifications' => array('notifications', false),
			'description'   => array('description', false),
			'creator_id' 	=> array('creator_id',	false),
			'backlinks'  	=> array('backlinks',	false),
			'timestamp'  	=> array('timestamp',	false),
			'name'   	=> array('name',	false)
		);
		return $sortable_columns;
	}
	public function prepare_items(){
		$per_page = 20;
		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();
 		$this->_column_headers = array( $columns, $hidden, $sortable );
		$data = $this->data;

        	function usort_reorder($a,$b){
            		$orderby = (!empty($_REQUEST['orderby'])) ? $_REQUEST['orderby'] : 'user_login';
			$order = (!empty($_REQUEST['order'])) ? $_REQUEST['order'] : 'asc';
			$result = strcmp($a[$orderby], $b[$orderby]);
			return ($order==='asc') ? $result : -$result;
		}
		usort($data, 'usort_reorder');
		$current_page = $this->get_pagenum();
		$total_items = count($data);
		$data = array_slice($data,(($current_page-1)*$per_page),$per_page);
		$this->items = $data;

	        $this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page'    => $per_page,
			'total_pages' => ceil($total_items/$per_page)
        	) );
	}
}
?>
