<?php

if(!class_exists('WP_List_Table')){
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class WpbcBacklinksTable extends WP_List_Table {

	private $data;
	private $wpdb;
	private $wpbcdb;

	public function __construct( $wpdb, $group_id  ){
		$this->wpdb 	= $wpdb;
		$this->wpbcdb 	= new WpbcDb( $this->wpdb );

		$this->data 	= $this->wpbcdb->get_backlinks( $group_id );
		parent::__construct( array(
			'singular'  => 'Backlink',
			'plural'    => 'Backlinks',
			'ajax'      => false
		) );	
	}
	public function column_default( $item, $column_name ){
        	switch( $column_name ){
            		case 'cb':
                		return '<input type="checkbox" />';
            		case 'site':
                		return $item['site'];
            		case 'url':
                		return $item['url'];
            		case 'expected_anchor':
				return '<a href="?page='. $_REQUEST['page'] .'&wpbc_gid='.
					$item['group_id'] . '&action=edit&edit='.
					$item['id'] . '">'. $item['expected_anchor'] .'</a>';
            		case 'discovered_anchor':
				if( ( $item['expected_anchor'] == '_' ) && ( $item['status'] > 0 ) ){
					return '';
				} else {
					return '<a href="?page='. $_REQUEST['page'] .'&wpbc_gid='.
						$item['group_id'] . '&action=edit&edit='.
						$item['id'] . '">'. $item['discovered_anchor'] .'</a>';
				}
            		case 'status':
				if( ( $item['expected_anchor'] == '_' ) && ( $item['status'] > 0 ) ){
					return 'Link exists';
				} else {
					return wpbc_process_status_code( $item['status'] );
				}
            		case 'timestamp':
                		return date("H:i D d M Y",  $item['timestamp']);
            		case 'created':
                		return date("d M Y",  $item['created']);
/*
            		case 'notifications':
                		$notify =  ($item['notify'] == 1) ? 'ON' : 'OFF';
                		$not =  ($item['notify'] == 1) ? 0 : 1;
				return '<a href="?page='. $_REQUEST['page'] .'&wpbc_gid='.
					$item['group_id'] .'&action=notify&notify='.
					$item['id'] .'&not='. $not .'">'. $notify .'</a>';
            		case 'notifications':
                		$notify =  ($item['notify'] == 1) ? 'ON' : 'OFF';
                		$not =  ($item['notify'] == 1) ? 0 : 1;
				return '<a href="?page='. $_REQUEST['page'] .'&wpbc_gid='.
					$item['group_id'] . '&action=edit&edit='.
					$item['id'] . '">'. $notify .'</a>';
            		case 'remind':
                		$remind =  ($item['remind_days'] > 0 ) ? $item['remind_days'] . ' days': 'Never';
				return '<a href="?page='. $_REQUEST['page'] .'&wpbc_gid='.
					$item['group_id'] . '&action=edit&edit='.
					$item['id'] . '">'. $remind .'</a>';
*/
            		default:
                		return '';
        	}
    	}
	public function column_cb( $item ){
		return '<input type="checkbox" name="wpbc_backlink_delete[]" value="'. $item['id'] .'"/>';
	}
	public function column_site( $item ){
		$actions = array(
				'edit'      => sprintf('<a href="?page=%s&wpbc_gid=%s&action=%s&edit=%s">Edit</a>', $_REQUEST['page'], $item['group_id'],'edit',$item['id']),
 			);
        	return sprintf('%1$s %2$s',	
        	    /*$1%s*/ $item['site'],
        	    /*$2%s*/ $this->row_actions($actions)
        	);
	}
	public function get_bulk_actions() {
        	$actions = array(
            		'delete'    	=> 'Delete',
            		'refresh'    	=> 'Refresh',
        		);
        	return $actions;
	}
	public function process_bulk_action() {
	}
	public function get_columns(){
		$columns = array(
			'cb'        		=> '<input type="checkbox" />',
			'site'  		=> 'Site To Check',
			'url'  			=> 'Your Url Link',
			'expected_anchor'    	=> 'Expected Anchor',
			'discovered_anchor'    	=> 'Discovered Anchor',
			'status'    		=> 'Status',
			'timestamp'    		=> 'Last Checked',
			'created'    		=> 'Created',
        	);
		return $columns;
	}  
	public function get_sortable_columns() {
		$sortable_columns = array(
			'discovered_anchor' 	=> array('discovered_anchor',	false),
			'expected_anchor'    	=> array('expected_anchor',	false),
			'timestamp'  		=> array('timestamp',		false),
			'download'  		=> array('download',		false),
			'created'  		=> array('created',		false),
			'status'  		=> array('status',		false),
			'site'   		=> array('site',		false),
			'name'   		=> array('name',		false),
			'url'  			=> array('url',			false)
		);
		return $sortable_columns;
	}
	public function prepare_items(){
		$per_page = 20;
		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();
 		$this->_column_headers = array( $columns, $hidden, $sortable );
		$data = $this->data;

        	function usort_reorder($a,$b){
            		$orderby = (!empty($_REQUEST['orderby'])) ? $_REQUEST['orderby'] : 'user_login';
			$order = (!empty($_REQUEST['order'])) ? $_REQUEST['order'] : 'asc';
			$result = strcmp($a[$orderby], $b[$orderby]);
			return ($order==='asc') ? $result : -$result;
		}
		usort($data, 'usort_reorder');
		$current_page = $this->get_pagenum();
		$total_items = count($data);
		$data = array_slice($data,(($current_page-1)*$per_page),$per_page);
		$this->items = $data;

	        $this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page'    => $per_page,
			'total_pages' => ceil($total_items/$per_page)
        	) );
	}
}
?>
